﻿using UnityEngine;
using System.Collections;
using System.Collections.Generic;

public class RotateByAccelerometer : MonoBehaviour
{
	public SerialHandler serialHandler;

	private List<Vector3> angleCache = new List<Vector3>();  
	public int angleCacheNum = 10;
	public Vector3 angle {
		private set { 
			angleCache.Add(value);
			if (angleCache.Count > angleCacheNum) {
				angleCache.RemoveAt(0);
			}  
		} 
		get {
			if (angleCache.Count > 0) { 
				var sum = Vector3.zero; 
 				angleCache.ForEach(angle => { sum += angle; });
				return sum / angleCache.Count;
			} else {
				return Vector3.zero;
			}
		}
	}
	
	void Start()
	{
		serialHandler.OnDataReceived += OnDataReceived;
	}
	
	void Update()
	{
		transform.rotation = Quaternion.Euler(angle);
	}
	 
	 

	void OnDataReceived(string message) //  reading data
	{   
		var data = message.Split(
			new string[]{"a"}, System.StringSplitOptions.None);   
		if (data.Length < 3) return;
		//float anglex = float.Parse(message);
		try {
			var angleX = float.Parse(data[0]);
			var angleY = float.Parse(data[1]);
			var angleZ = float.Parse (data[2]);
			angle = new Vector3(angleX, angleY, angleZ);
		} catch (System.Exception e) {
			Debug.LogWarning(e.Message);
		}
		  
	}

}
